@@ -25,7 +25,7 @@
 #include "utils.h"
 #include "gm_crypt.h"
 #include "base64.h"
-#include "gearman.h"
+#include "gearman_utils.h"
 #include "popenRWE.h"
 #include "polarssl/md5.h"
 
@@ -139,11 +139,13 @@ int mod_gm_encrypt(char ** encrypted, char * text, int mode) {
 
 /* decrypt text with given key */
 void mod_gm_decrypt(char ** decrypted, char * text, int mode) {
+    char *test;
     unsigned char * buffer = malloc(sizeof(unsigned char) * GM_BUFFERSIZE);
 
     /* first decode from base64 */
     size_t bsize = base64_decode(text, buffer, GM_BUFFERSIZE);
-    if(mode == GM_ENCODE_AND_ENCRYPT) {
+    test = strndup(buffer, 5);
+    if(mode == GM_ENCODE_AND_ENCRYPT || (mode == GM_ENCODE_ACCEPT_ALL && strcmp(test, "type="))) {
         /* then decrypt */
         mod_gm_aes_decrypt(decrypted, buffer, bsize);
     }
@@ -153,6 +155,7 @@ void mod_gm_decrypt(char ** decrypted, char * text, int mode) {
         debase64[bsize] = '\0';
         strcpy(*decrypted, debase64);
     }
+    free(test);
     free(buffer);
     return;
 }
@@ -226,11 +229,13 @@ int set_default_options(mod_gm_opt_t *opt) {
     opt->logmode            = GM_LOG_MODE_AUTO;
     opt->logfile_fp         = NULL;
     opt->message            = NULL;
+    opt->delimiter          = strdup("\t");
     opt->return_code        = 0;
     opt->timeout            = 10;
     opt->debug_level        = GM_LOG_INFO;
     opt->perfdata           = GM_DISABLED;
     opt->perfdata_mode      = GM_PERFDATA_OVERWRITE;
+    opt->use_uniq_jobs      = GM_ENABLED;
     opt->do_hostchecks      = GM_ENABLED;
     opt->hosts              = GM_DISABLED;
     opt->services           = GM_DISABLED;
@@ -248,12 +253,18 @@ int set_default_options(mod_gm_opt_t *opt) {
     opt->idle_timeout       = GM_DEFAULT_IDLE_TIMEOUT;
     opt->max_jobs           = GM_DEFAULT_MAX_JOBS;
     opt->spawn_rate         = GM_DEFAULT_SPAWN_RATE;
+    opt->timeout_return     = 2;
     opt->identifier         = NULL;
     opt->queue_cust_var     = NULL;
     opt->show_error_output  = GM_ENABLED;
     opt->dup_results_are_passive = GM_ENABLED;
     opt->orphan_host_checks      = GM_ENABLED;
     opt->orphan_service_checks   = GM_ENABLED;
+    opt->accept_clear_results    = GM_DISABLED;
+    opt->has_starttime      = FALSE;
+    opt->has_finishtime     = FALSE;
+    opt->has_latency        = FALSE;
+    opt->active             = GM_DISABLED;
 
     opt->workaround_rc_25   = GM_DISABLED;
 
@@ -326,9 +337,15 @@ int parse_yes_or_no(char*value, int dfl) {
 
 /* parse one line of args into the given struct */
 int parse_args_line(mod_gm_opt_t *opt, char * arg, int recursion_level) {
-    int x;
+    int i, x, number, callback_num;
     char *key;
     char *value;
+    char *callback;
+    char *export_queue;
+    char *return_code;
+    int return_code_num;
+    char *callbacks;
+    char * type;
 
     gm_log( GM_LOG_TRACE, "parse_args_line(%s, %d)\n", arg, recursion_level);
 
@@ -346,9 +363,13 @@ int parse_args_line(mod_gm_opt_t *opt, char * arg, int recursion_level) {
     while(key[0] == '-')
         key++;
 
-    /* daemon mode */
+    /* daemon mode or delimiter */
     if ( !strcmp( key, "daemon" ) ||  !strcmp( key, "d" ) ) {
         opt->daemon_mode = parse_yes_or_no(value, GM_ENABLED);
+        if(value != NULL) {
+            free(opt->delimiter);
+            opt->delimiter = strdup( value );
+        }
         return(GM_OK);
     }
 
@@ -442,6 +463,12 @@ int parse_args_line(mod_gm_opt_t *opt, char * arg, int recursion_level) {
         return(GM_OK);
     }
 
+    /* accept_clear_results */
+    else if ( !strcmp( key, "accept_clear_results" ) ) {
+        opt->accept_clear_results = parse_yes_or_no(value, GM_ENABLED);
+        return(GM_OK);
+    }
+
     /* enable_embedded_perl */
     else if ( !strcmp( key, "enable_embedded_perl" ) ) {
 #ifdef EMBEDDEDPERL
@@ -467,6 +494,12 @@ int parse_args_line(mod_gm_opt_t *opt, char * arg, int recursion_level) {
         return(GM_OK);
     }
 
+    /* use_uniq_jobs */
+    else if ( !strcmp( key, "use_uniq_jobs" ) ) {
+        opt->use_uniq_jobs = parse_yes_or_no(value, GM_ENABLED);
+        return(GM_OK);
+    }
+
     else if ( value == NULL ) {
         gm_log( GM_LOG_ERROR, "unknown switch '%s'\n", key );
         return(GM_OK);
@@ -532,6 +565,12 @@ int parse_args_line(mod_gm_opt_t *opt, char * arg, int recursion_level) {
         opt->message = strdup( value );
     }
 
+    /* delimiter */
+    else if (   !strcmp( key, "delimiter" ) ) {
+        free(opt->delimiter);
+        opt->delimiter = strdup( value );
+    }
+
     /* host */
     else if (   !strcmp( key, "host" ) ) {
         opt->host = strdup( value );
@@ -544,16 +583,19 @@ int parse_args_line(mod_gm_opt_t *opt, char * arg, int recursion_level) {
 
     /* latency */
     else if ( !strcmp( key, "latency" ) ) {
+        opt->has_latency = TRUE;
         string2timeval(value, &opt->latency);
     }
 
     /* start time */
     else if ( !strcmp( key, "starttime" ) ) {
+        opt->has_starttime = TRUE;
         string2timeval(value, &opt->starttime);
     }
 
     /* finish time */
     else if ( !strcmp( key, "finishtime" ) ) {
+        opt->has_finishtime = TRUE;
         string2timeval(value, &opt->finishtime);
     }
 
@@ -598,7 +640,8 @@ int parse_args_line(mod_gm_opt_t *opt, char * arg, int recursion_level) {
     }
 
     /* timeout */
-    else if ( !strcmp( key, "timeout" ) ) {
+    else if (   !strcmp( key, "timeout" )
+             || !strcmp( key, "t" )) {
         opt->timeout = atoi( value );
         if(opt->timeout < 0) { opt->timeout = 10; }
     }
@@ -645,6 +688,13 @@ int parse_args_line(mod_gm_opt_t *opt, char * arg, int recursion_level) {
         if(opt->spawn_rate < 0) { opt->spawn_rate = GM_DEFAULT_SPAWN_RATE; }
     }
 
+    /* timeout_return */
+    else if ( !strcmp( key, "timeout_return" ) ) {
+        opt->timeout_return = atoi( value );
+        if(opt->timeout_return < 0) { opt->timeout_return = 2; }
+        if(opt->timeout_return > 3) { opt->timeout_return = 2; }
+    }
+
     /* perfdata_mode */
     else if ( !strcmp( key, "perfdata_mode" ) ) {
         opt->perfdata_mode = atoi( value );
@@ -745,24 +795,21 @@ int parse_args_line(mod_gm_opt_t *opt, char * arg, int recursion_level) {
 
     /* export queues */
     else if ( !strcmp( key, "export" ) ) {
-        char *callback;
-        char *export_queue;
         export_queue        = strsep( &value, ":" );
         export_queue        = trim(export_queue);
-        char *return_code   = strsep( &value, ":" );
-        int return_code_num = atoi(return_code);
-        char *callbacks     = strsep( &value, ":" );
+        return_code         = strsep( &value, ":" );
+        return_code_num     = atoi(return_code);
+        callbacks           = strsep( &value, ":" );
         if(strlen(export_queue) > 50) {
             gm_log( GM_LOG_ERROR, "export queue name '%s' is too long, please use a maximum of 50 characters\n", export_queue );
         } else {
             while ( (callback = strsep( &callbacks, "," )) != NULL ) {
-                int callback_num = atoi(trim(callback));
+                callback_num = atoi(trim(callback));
                 if(index(callback, 'N') != NULL) {
                     callback_num = -1;
                     /* get neb callback number by name */
-                    int i;
                     for(i=0;i<GM_NEBTYPESSIZE;i++) {
-                        char * type = nebcallback2str(i);
+                        type = nebcallback2str(i);
                         if(!strcmp(type, callback)) {
                             callback_num = i;
                         }
@@ -774,7 +821,7 @@ int parse_args_line(mod_gm_opt_t *opt, char * arg, int recursion_level) {
                     }
                 }
 
-                int number = opt->exports[callback_num]->elem_number;
+                number = opt->exports[callback_num]->elem_number;
                 opt->exports[callback_num]->name[number]        = strdup(export_queue);
                 opt->exports[callback_num]->return_code[number] = return_code_num;
                 opt->exports[callback_num]->elem_number++;
@@ -946,7 +993,11 @@ void dumpconfig(mod_gm_opt_t *opt, int mode) {
             gm_log( GM_LOG_DEBUG, "encryption key:      not set\n" );
         }
     }
+    if(mode == GM_NEB_MODE) {
+        gm_log( GM_LOG_DEBUG, "accept clear result: %s\n", opt->accept_clear_results == GM_ENABLED ? "yes" : "no");
+    }
     gm_log( GM_LOG_DEBUG, "transport mode:      %s\n", opt->encryption == GM_ENABLED ? "aes-256+base64" : "base64 only");
+    gm_log( GM_LOG_DEBUG, "use uniq jobs:       %s\n", opt->use_uniq_jobs == GM_ENABLED ? "overwrite" : "append");
 
     gm_log( GM_LOG_DEBUG, "--------------------------------\n" );
     return;
@@ -955,9 +1006,9 @@ void dumpconfig(mod_gm_opt_t *opt, int mode) {
 
 /* free options structure */
 void mod_gm_free_opt(mod_gm_opt_t *opt) {
+    int i,j;
     if(opt == NULL)
         return;
-    int i,j;
     for(i=0;i<opt->server_num;i++) {
         free(opt->server_list[i]->host);
         free(opt->server_list[i]);
@@ -983,6 +1034,7 @@ void mod_gm_free_opt(mod_gm_opt_t *opt) {
     free(opt->crypt_key);
     free(opt->keyfile);
     free(opt->message);
+    free(opt->delimiter);
     free(opt->pidfile);
     free(opt->logfile);
     free(opt->host);
@@ -1202,8 +1254,6 @@ void escape(char *out, int ch) {
             strcpy(out, "\\a"); break;
         case '\\':
             strcpy(out, "\\\\"); break;
-        //case '\'':
-        //    strcpy(out, "\\\'"); break;
         case '\"':
             strcpy(out, "\\\""); break;
         default:
@@ -1729,6 +1779,7 @@ char *md5sum(char *text) {
 
 /* add parsed server to list */
 void add_server(int * server_num, gm_server_t * server_list[GM_LISTSIZE], char * servername) {
+    gm_server_t *new_server;
     char * server   = strdup( servername );
     char * server_c = server;
     char * host     = strsep( &server, ":" );
@@ -1737,7 +1788,6 @@ void add_server(int * server_num, gm_server_t * server_list[GM_LISTSIZE], char *
     if(port_val != NULL) {
         port  = ( in_port_t ) atoi( port_val );
     }
-    gm_server_t *new_server;
     new_server = malloc(sizeof(gm_server_t));
     if(!strcmp(host, "")) {
         new_server->host = strdup("localhost");
