@@ -54,7 +54,7 @@
 #define MOD_GM_COMMON_H
 
 /* constants */
-#define GM_VERSION                 "1.2.8"
+#define GM_VERSION                 "1.3.6"
 #define GM_ENABLED                      1
 #define GM_DISABLED                     0
 #define GM_BUFFERSIZE               98304
@@ -93,7 +93,7 @@
 
 #define GM_DEFAULT_JOB_TIMEOUT         60
 #define GM_DEFAULT_JOB_RETRIES          1
-#define GM_CHILD_SHUTDOWN_TIMEOUT      30
+#define GM_CHILD_SHUTDOWN_TIMEOUT      10
 #define GM_DEFAULT_RESULT_QUEUE  "check_results"
 #define GM_DEFAULT_IDLE_TIMEOUT        10
 #define GM_DEFAULT_MAX_JOBS          1000
@@ -193,6 +193,7 @@ typedef struct mod_gm_opt_struct {
     int            logmode;                                 /**< logmode: auto, syslog, file or nagios */
     char         * logfile;                                 /**< path for the logfile */
     FILE         * logfile_fp;                              /**< filedescriptor for the logfile */
+    int            use_uniq_jobs;                           /**< flag whether normal jobs will be sent with/without uniq set */
 /* neb module */
     char         * result_queue;                            /**< name of the result queue used by the neb module */
     int            result_workers;                          /**< number of result worker threads started */
@@ -222,6 +223,7 @@ typedef struct mod_gm_opt_struct {
     int            max_jobs;                                /**< maximum number of jobs done after a worker exits */
     int            spawn_rate;                              /**< number of spawned new worker */
     int            show_error_output;                       /**< optional display the stderr output of plugins */
+    int            timeout_return;                          /**< timeout return code */
     int            dup_results_are_passive;                 /**< send duplicate results as passive checks */
 #ifdef EMBEDDEDPERL
     int            enable_embedded_perl;                    /**< enabled embedded perl */
@@ -236,9 +238,13 @@ typedef struct mod_gm_opt_struct {
     char         * message;                                 /**< message output */
     char         * host;                                    /**< hostname for this check */
     char         * service;                                 /**< service description for this check */
+    char         * delimiter;                               /**< delimiter to cut check results */
     int            active;                                  /**< flag wheter the result is a active or a passive check */
+    int            has_starttime;                           /**< flag when starttime is set */
     struct timeval starttime;                               /**< time when the check started */
+    int            has_finishtime;                          /**< flag when finishtime is set */
     struct timeval finishtime;                              /**< time when the check finished */
+    int            has_latency;                             /**< flag when latency is set */
     struct timeval latency;                                 /**< latency for this result */
 } mod_gm_opt_t;
 
