@@ -606,7 +606,7 @@ static int handle_host_check( int event_type, void *data ) {
     if(add_job_to_queue( &client,
                          mod_gm_opt->server_list,
                          target_queue,
-                         hst->name,
+                        (mod_gm_opt->use_uniq_jobs == GM_ENABLED ? hst->name : NULL),
                          temp_buffer,
                          GM_JOB_PRIO_NORMAL,
                          GM_DEFAULT_JOB_RETRIES,
@@ -783,7 +783,7 @@ static int handle_svc_check( int event_type, void *data ) {
     if(add_job_to_queue( &client,
                          mod_gm_opt->server_list,
                          target_queue,
-                         uniq,
+                        (mod_gm_opt->use_uniq_jobs == GM_ENABLED ? uniq : NULL),
                          temp_buffer,
                          prio,
                          GM_DEFAULT_JOB_RETRIES,
