@@ -36,10 +36,14 @@ int main (int argc, char **argv, char **env) {
     gm_job_t * exec_job;
     exec_job = ( gm_job_t * )malloc( sizeof *exec_job );
     set_default_job(exec_job, mod_gm_opt);
-    //strcpy(cmd, "/bin/true;");
-    strcpy(cmd, "/bin/true;");
-    //strcpy(cmd, "./t/both");
+    strcpy(cmd, "BLAH=BLUB /bin/hostname");
+    printf("this should be popen\n");
+    run_check(cmd, &result, &error);
+    free(result);
+    free(error);
 
+    strcpy(cmd, "/bin/hostname");
+    printf("this should be execvp\n");
     run_check(cmd, &result, &error);
     free(result);
     free(error);
@@ -55,7 +59,7 @@ int main (int argc, char **argv, char **env) {
     free_job(exec_job);
     mod_gm_free_opt(mod_gm_opt);
 #ifdef EMBEDDEDPERL
-    deinit_embedded_perl();
+    deinit_embedded_perl(0);
 #endif
     exit(0);
 }
