@@ -44,12 +44,15 @@ char **start_env;
 /* work starts here */
 #ifdef EMBEDDEDPERL
 int main (int argc, char **argv, char **env) {
-    start_env=env;
     struct stat stat_buf;
 #else
 int main (int argc, char **argv) {
 #endif
     int sid, x;
+#ifdef EMBEDDEDPERL
+    start_env=env;
+#endif
+
     last_time_increased = 0;
 
     /* store the original command line for later reloads */
@@ -590,6 +593,16 @@ void clean_exit(int sig) {
     if(shmdt(shm) < 0)
         perror("shmdt");
 
+    /*
+     * clean up shared memory
+     * will be removed when last client detaches
+     */
+    if( shmctl( shmid, IPC_RMID, 0 ) == -1 ) {
+        perror("shmctl");
+    } else {
+        gm_log( GM_LOG_DEBUG, "shared memory deleted\n");
+    }
+
     gm_log( GM_LOG_INFO, "mod_gearman worker exited\n");
     mod_gm_free_opt(mod_gm_opt);
     exit( EXIT_SUCCESS );
@@ -618,7 +631,7 @@ void stop_children(int mode) {
         for(x=3; x < mod_gm_opt->max_worker+4; x++) {
             curpid = shm[x];
             if(curpid < 0) { curpid = -curpid; }
-            if( curpid != 0 ) {
+            if( curpid != 0 && curpid != 1 ) {
                 kill(curpid, SIGTERM);
             }
         }
@@ -646,11 +659,15 @@ void stop_children(int mode) {
         for(x=3; x < mod_gm_opt->max_worker+4; x++) {
             curpid = shm[x];
             if(curpid < 0) { curpid = -curpid; }
-            if( curpid != 0 ) {
+            if( curpid != 0 && curpid != 1 ) {
                 kill(curpid, SIGINT);
             }
         }
 
+        /* wait 3 more seconds*/
+        if(current_number_of_workers > 0)
+            sleep(3);
+
         while((chld = waitpid(-1, &status, WNOHANG)) != -1 && chld > 0) {
             gm_log( GM_LOG_TRACE, "wait() %d exited with %d\n", chld, status);
         }
@@ -674,16 +691,6 @@ void stop_children(int mode) {
         if(current_number_of_workers == 0)
             return;
 
-        /*
-         * clean up shared memory
-         * will be removed when last client detaches
-         */
-        if( shmctl( shmid, IPC_RMID, 0 ) == -1 ) {
-            perror("shmctl");
-        } else {
-            gm_log( GM_LOG_TRACE, "shared memory deleted\n");
-        }
-
         /* this will kill us too */
         gm_log( GM_LOG_ERROR, "exiting by SIGKILL...\n");
         killpg(0, SIGKILL);
