@@ -143,7 +143,6 @@ void worker_loop() {
 /* get a job */
 void *get_job( gearman_job_st *job, void *context, size_t *result_size, gearman_return_t *ret_ptr ) {
     sigset_t block_mask;
-    sigset_t old_mask;
     int wsize, valid_lines;
     char workload[GM_BUFFERSIZE];
     char * decrypted_data;
@@ -174,7 +173,7 @@ void *get_job( gearman_job_st *job, void *context, size_t *result_size, gearman_
     /* ignore sigterms while running job */
     sigemptyset(&block_mask);
     sigaddset(&block_mask, SIGTERM);
-    sigprocmask(SIG_BLOCK, &block_mask, &old_mask);
+    sigprocmask(SIG_BLOCK, &block_mask, NULL);
 
     /* get the data */
     current_gearman_job = job;
@@ -271,7 +270,7 @@ void *get_job( gearman_job_st *job, void *context, size_t *result_size, gearman_
     current_gearman_job = NULL;
 
     /* start listening to SIGTERMs */
-    sigprocmask(SIG_SETMASK, &old_mask, NULL);
+    sigprocmask(SIG_UNBLOCK, &block_mask, NULL);
 
     free(decrypted_orig);
     free(decrypted_data_c);
@@ -478,8 +477,14 @@ void clean_worker_exit(int sig) {
 
     /* clear gearmans job, otherwise it would be retried and retried */
     if(current_gearman_job != NULL) {
-        send_failed_result(current_job, sig);
-        gearman_job_send_complete(current_gearman_job, NULL, 0);
+        if(sig == 2) {
+            /* if worker stopped with sigint, let the job retry */
+        } else {
+            send_failed_result(current_job, sig);
+            gearman_job_send_complete(current_gearman_job, NULL, 0);
+        }
+        /* make sure no processes are left over */
+        kill_child_checks();
     }
 
     gm_log( GM_LOG_TRACE, "cleaning worker\n");
@@ -490,7 +495,7 @@ void clean_worker_exit(int sig) {
     mod_gm_free_opt(mod_gm_opt);
 
 #ifdef EMBEDDEDPERL
-    deinit_embedded_perl();
+    deinit_embedded_perl(0);
 #endif
 
     if(worker_run_mode == GM_WORKER_STANDALONE)
